@@ -3,11 +3,11 @@
 #' @author Lukasz Andrzejewski
 #' @return full names and abbreviations of months
 
-get_months<-function(){
-  months<- tolower(c("January", "February", "March", "April", "May", "June", "July", "August",
-                     "September", "October", "November", "December",
-                     "Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep",
-                     "Oct",	"Nov","Dec"))
+get_months <- function() {
+  months <- tolower(c("January", "February", "March", "April", "May", "June", "July",
+                      "August", "September", "October", "November", "December",
+                     "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
+                     "Oct",	"Nov", "Dec"))
   return(months)
 }
 
@@ -16,9 +16,9 @@ get_months<-function(){
 #' @author Lukasz Andrzejewski
 #' @return full names of months
 
-get_months_full_names<-function(){
-  months<- tolower(c("January", "February", "March", "April", "May", "June", "July", "August",
-                     "September", "October", "November", "December"))
+get_months_full_names <- function() {
+  months <- tolower(c("January", "February", "March", "April", "May", "June", "July",
+                     "August", "September", "October", "November", "December"))
   return(months)
 }
 
@@ -27,8 +27,8 @@ get_months_full_names<-function(){
 #' @author Lukasz Andrzejewski
 #' @return full names and abbreviations of months separated by vertical bar
 
-get_months_sep_by_vertical_bar<- function(){
-  months_sep_by_vertical_bar<- paste(get_months(),sep="",collapse="|")
+get_months_sep_by_vertical_bar <- function() {
+  months_sep_by_vertical_bar <- paste(get_months(), sep = "", collapse = "|")
   return(months_sep_by_vertical_bar)
 }
 
@@ -37,8 +37,8 @@ get_months_sep_by_vertical_bar<- function(){
 #' @author Lukasz Andrzejewski
 #' @return full names and abbreviations of months separated by vertical bar
 
-get_full_name_months_sep_by_vertical_bar<- function(){
-  months_sep_by_vertical_bar<- paste(get_months_full_names(),sep="",collapse="|")
+get_full_name_months_sep_by_vertical_bar <- function()  {
+  months_sep_by_vertical_bar <- paste(get_months_full_names(), sep = "", collapse = "|")
   return(months_sep_by_vertical_bar)
 }
 
@@ -48,12 +48,12 @@ get_full_name_months_sep_by_vertical_bar<- function(){
 #' @author Lukasz Andrzejewski
 #' @return vector, if any full length month name, then replace by abbreviated month name
 
-get_abbreviated_month_name<-function(df_column){
+get_abbreviated_month_name <- function(df_column)  {
   month_abbreviations <- c("january" = "Jan", "february" = "Feb", "march" = "Mar",
                            "april" = "Apr", "may" = "May", "june" = "Jun",
                            "july" = "Jul", "august" = "Aug", "september" = "Sep",
                            "october" = "Oct", "november" = "Nov", "december" = "Dec")
-  replace_full_month_name_by_abb <- ifelse(grepl(get_full_name_months_sep_by_vertical_bar(),tolower(df_column)),
+  replace_full_month_name_by_abb <- ifelse(grepl(get_full_name_months_sep_by_vertical_bar(), tolower(df_column)),
                                                                                           stringr::str_replace_all(tolower(df_column), month_abbreviations),
                                                                                           df_column)
   return(replace_full_month_name_by_abb)
@@ -65,8 +65,8 @@ get_abbreviated_month_name<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return return up to 12 characters
 
-get_up_to_12_char<-function(df_column){
-  substr_up_to_12_chars<-substr(df_column,0,12)
+get_up_to_12_char <- function(df_column)  {
+  substr_up_to_12_chars <- substr(df_column, 0, 12)
   return(substr_up_to_12_chars)
 }
 
@@ -76,8 +76,8 @@ get_up_to_12_char<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return special characters: "-|\\/|\\w+\\s+"
 
-has_dash_or_slash_or_white_space_characters_separated_by_vertical_bar <- function(special_characters=c("-","\\/","\\w+\\s+")){
-  special_char_sep_by_vertical_bar<- paste(special_characters,sep="",collapse="|")
+has_dash_or_slash_or_white_space_characters_separated_by_vertical_bar <- function(special_characters=c("-", "\\/", "\\w+\\s+"))  {
+  special_char_sep_by_vertical_bar <- paste(special_characters, sep = "", collapse = "|")
   return(special_char_sep_by_vertical_bar)
 
 }
@@ -86,9 +86,9 @@ has_dash_or_slash_or_white_space_characters_separated_by_vertical_bar <- functio
 #' @author Lukasz Andrzejewski
 #' @return special characters and months: "-|\\/|\\w+\\s+|january|february|march|april|may|june|july|august|september|october|november|december|jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec"
 
-has_dash_or_slash_or_white_space_characters_or_months_separated_by_vertical_bar <- function(){
+has_dash_or_slash_or_white_space_characters_or_months_separated_by_vertical_bar <- function()  {
   special_char_and_months_sep_by_vertical_bar<-paste(has_dash_or_slash_or_white_space_characters_separated_by_vertical_bar(),
-                                                     get_months_sep_by_vertical_bar(),sep="|")
+                                                     get_months_sep_by_vertical_bar(), sep = "|")
   return(special_char_and_months_sep_by_vertical_bar)
 }
 
@@ -99,12 +99,12 @@ has_dash_or_slash_or_white_space_characters_or_months_separated_by_vertical_bar
 #' @return logical vector, return TRUE if number of characters is higher than 5, contains digits and special characters
 #' or month names
 
-find_only_dates<-function(df_column){
-  df_column<-get_abbreviated_month_name(df_column)
-  df_column<-get_up_to_12_char(df_column)
-  find_date<-grepl(has_dash_or_slash_or_white_space_characters_or_months_separated_by_vertical_bar(),tolower(df_column)) &
-              grepl("[[:digit:]]",df_column) & nchar(df_column)>=6 &
-              !is.na(df_column) & df_column!=" " & !find_unknow_date(df_column)
+find_only_dates <- function(df_column) {
+  df_column <- get_abbreviated_month_name(df_column)
+  df_column <- get_up_to_12_char(df_column)
+  find_date <- grepl(has_dash_or_slash_or_white_space_characters_or_months_separated_by_vertical_bar(), tolower(df_column)) &
+              grepl("[[:digit:]]",df_column) & nchar(df_column) >= 6 &
+              !is.na(df_column) & df_column != " " & !find_unknow_date(df_column)
   return(find_date)
 }
 
@@ -113,8 +113,8 @@ find_only_dates<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if "un" character is found but not "jun"
-find_unknow_date<-function(df_column){
-  unknown_date<-grepl("[^j]un",tolower(df_column))
+find_unknow_date <- function(df_column) {
+  unknown_date <- grepl("[^j]un",tolower(df_column))
   return(unknown_date)
 }
 
@@ -127,8 +127,8 @@ find_unknow_date<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return by default delete semicolon, colon and plus sign from vector or data frame
 
-remove_no_date_characters<- function(df_column,symbols="[;:+]"){
-  df_column<-stringr::str_replace_all(df_column, pattern = symbols, replacement = "")
+remove_no_date_characters <- function(df_column,symbols="[;:+]") {
+  df_column <- stringr::str_replace_all(df_column, pattern = symbols, replacement = "")
   return(df_column)
 }
 
@@ -138,8 +138,8 @@ remove_no_date_characters<- function(df_column,symbols="[;:+]"){
 #' @param symbol symbol that needs to be found, by default "T"
 #' @author Lukasz Andrzejewski
 #' @return number of found symbols
-get_number_of_symbols_in_string<-function(df_column,symbol="T"){
-  n_of_symbols<-stringr::str_count(toupper(df_column), symbol)
+get_number_of_symbols_in_string <- function(df_column, symbol = "T")  {
+  n_of_symbols <- stringr::str_count(toupper(df_column), symbol)
   return(n_of_symbols)
 }
 
@@ -149,9 +149,9 @@ get_number_of_symbols_in_string<-function(df_column,symbol="T"){
 #' @param symbol symbol that needs to be found, by default "T"
 #' @author Lukasz Andrzejewski
 #' @return substring of date from position 1 to position where last "symbol" is located
-remove_unnecessary_part_of_date<- function(df_column,symbol="T"){
-  last_symbol_position<-unlist(gregexpr(symbol,toupper(df_column)))[-1]
-  substring_from_1_to_last_symbol<-substr(df_column,1,last_symbol_position - 1)
+remove_unnecessary_part_of_date <-  function(df_column, symbol = "T")  {
+  last_symbol_position <- unlist(gregexpr(symbol, toupper(df_column)))[-1]
+  substring_from_1_to_last_symbol <- substr(df_column, 1, last_symbol_position - 1)
   return(substring_from_1_to_last_symbol)
 }
 
@@ -162,24 +162,24 @@ remove_unnecessary_part_of_date<- function(df_column,symbol="T"){
 #' @return output up to 12 characters, remove whitespace from start and end of string, keep characters from
 #' the left site of letter "T"
 
-prepare_date<-function(df_column){
-  df_column<-get_abbreviated_month_name(df_column)
-  df_column<-get_up_to_12_char(df_column)
-  df_column<-remove_no_date_characters(df_column)
-  df_column<-stringr::str_trim(df_column)
-  df_column_ymd<-ifelse(grepl("T",toupper(df_column)) &
+prepare_date <- function(df_column)  {
+  df_column <- get_abbreviated_month_name(df_column)
+  df_column <- get_up_to_12_char(df_column)
+  df_column <- remove_no_date_characters(df_column)
+  df_column <- stringr::str_trim(df_column)
+  df_column_ymd <- ifelse(grepl("T", toupper(df_column)) &
                           !is.na(df_column) &
-                          get_number_of_symbols_in_string(df_column)==1 &
-                          !grepl("august|october|oct",df_column,ignore.case = TRUE),
-                stringr::str_split_fixed(toupper(df_column),"T",n=2)[,1],
+                          get_number_of_symbols_in_string(df_column) == 1 &
+                          !grepl("august|october|oct", df_column,ignore.case = TRUE),
+                stringr::str_split_fixed(toupper(df_column), "T", n = 2)[,1],
 
-                ifelse(grepl("T",toupper(df_column)) &
+                ifelse(grepl("T", toupper(df_column)) &
                 !is.na(df_column) &
-                get_number_of_symbols_in_string(df_column)>1,
+                get_number_of_symbols_in_string(df_column) > 1,
                 remove_unnecessary_part_of_date(df_column),
 
-                ifelse(nchar(stringr::str_split_fixed(df_column, " ",n=4)[,1])>4,
-                stringr::str_split_fixed(df_column, " ",n=4)[,1],
+                ifelse(nchar(stringr::str_split_fixed(df_column, " ", n = 4)[,1]) > 4,
+                stringr::str_split_fixed(df_column, " ", n = 4)[,1],
                 df_column)))
 
   return(df_column_ymd)
@@ -191,10 +191,10 @@ prepare_date<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is YMD
 
-find_ymd_date_format<-function(df_column){
-  prepare_ymd_date<-prepare_date(df_column)
-  ymd_date<-suppressWarnings({!(is.na(prepare_ymd_date) | is.na(lubridate::ymd(prepare_ymd_date)) |
-                                  prepare_ymd_date=="" | prepare_ymd_date==" ")})
+find_ymd_date_format <- function(df_column)  {
+  prepare_ymd_date <- prepare_date(df_column)
+  ymd_date <- suppressWarnings({!(is.na(prepare_ymd_date) | is.na(lubridate::ymd(prepare_ymd_date)) |
+                                  prepare_ymd_date == "" | prepare_ymd_date == " ")})
   return(ymd_date)
 }
 
@@ -204,10 +204,10 @@ find_ymd_date_format<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is DMY
 
-find_dmy_date_format<-function(df_column){
-  prepare_dmy_date<-prepare_date(df_column)
-  dmy_date<-suppressWarnings({!(is.na(prepare_dmy_date) | is.na(lubridate::dmy(prepare_dmy_date)) |
-                                  prepare_dmy_date=="" | prepare_dmy_date==" ")})
+find_dmy_date_format <- function(df_column)  {
+  prepare_dmy_date <- prepare_date(df_column)
+  dmy_date <- suppressWarnings({!(is.na(prepare_dmy_date) | is.na(lubridate::dmy(prepare_dmy_date)) |
+                                  prepare_dmy_date == "" | prepare_dmy_date == " ")})
   return(dmy_date)
 }
 
@@ -217,10 +217,10 @@ find_dmy_date_format<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is MDY
 
-find_mdy_date_format<-function(df_column){
-  prepare_mdy_date<-prepare_date(df_column)
-  mdy_date<-suppressWarnings({!(is.na(prepare_mdy_date) | is.na(lubridate::mdy(prepare_mdy_date)) |
-                                  prepare_mdy_date=="" | prepare_mdy_date==" ")})
+find_mdy_date_format <- function(df_column)  {
+  prepare_mdy_date <- prepare_date(df_column)
+  mdy_date <- suppressWarnings({!(is.na(prepare_mdy_date) | is.na(lubridate::mdy(prepare_mdy_date)) |
+                                  prepare_mdy_date == "" | prepare_mdy_date == " ")})
   return(mdy_date)
 }
 
@@ -230,10 +230,10 @@ find_mdy_date_format<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is MYD
 
-find_myd_date_format<-function(df_column){
-  prepare_myd_date<-prepare_date(df_column)
-  myd_date<-suppressWarnings({!(is.na(prepare_myd_date) | is.na(lubridate::myd(prepare_myd_date)) |
-                                  prepare_myd_date=="" | prepare_myd_date==" ")})
+find_myd_date_format <- function(df_column)  {
+  prepare_myd_date <- prepare_date(df_column)
+  myd_date <- suppressWarnings({!(is.na(prepare_myd_date) | is.na(lubridate::myd(prepare_myd_date)) |
+                                  prepare_myd_date == "" | prepare_myd_date == " ")})
   return(myd_date)
 }
 
@@ -243,10 +243,10 @@ find_myd_date_format<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is YDM
 
-find_ydm_date_format<-function(df_column){
-  prepare_ydm_date<-prepare_date(df_column)
-  ydm_date<-suppressWarnings({!(is.na(prepare_ydm_date) | is.na(lubridate::ydm(prepare_ydm_date)) |
-                                  prepare_ydm_date=="" | prepare_ydm_date==" ")})
+find_ydm_date_format <- function(df_column)  {
+  prepare_ydm_date <- prepare_date(df_column)
+  ydm_date <- suppressWarnings({!(is.na(prepare_ydm_date) | is.na(lubridate::ydm(prepare_ydm_date)) |
+                                  prepare_ydm_date == "" | prepare_ydm_date == " ")})
   return(ydm_date)
 }
 
@@ -257,10 +257,10 @@ find_ydm_date_format<-function(df_column){
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if date format is DYM
 
-find_dym_date_format<-function(df_column){
-  prepare_dym_date<-prepare_date(df_column)
-  dym_date<-suppressWarnings({!(is.na(prepare_dym_date) | is.na(lubridate::dym(prepare_dym_date)) |
-                                  prepare_dym_date=="" | prepare_dym_date==" ")})
+find_dym_date_format <- function(df_column)  {
+  prepare_dym_date <- prepare_date(df_column)
+  dym_date <- suppressWarnings({!(is.na(prepare_dym_date) | is.na(lubridate::dym(prepare_dym_date)) |
+                                  prepare_dym_date == "" | prepare_dym_date == " ")})
   return(dym_date)
 }
 
@@ -270,16 +270,16 @@ find_dym_date_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return return score of most probable date format
-get_max_score_within_data_formats<-function(df_column){
-  ymd_score<-sum(find_ymd_date_format(df_column))
-  ydm_score<-sum(find_ydm_date_format(df_column))
-  dmy_score<-sum(find_dmy_date_format(df_column))
-  dym_score<-sum(find_dym_date_format(df_column))
-  mdy_score<-sum(find_mdy_date_format(df_column))
-  myd_score<-sum(find_myd_date_format(df_column))
+get_max_score_within_data_formats <- function(df_column)  {
+  ymd_score <- sum(find_ymd_date_format(df_column))
+  ydm_score <- sum(find_ydm_date_format(df_column))
+  dmy_score <- sum(find_dmy_date_format(df_column))
+  dym_score <- sum(find_dym_date_format(df_column))
+  mdy_score <- sum(find_mdy_date_format(df_column))
+  myd_score <- sum(find_myd_date_format(df_column))
 
-  all_scores<-c(ymd_score,ydm_score,dmy_score,dym_score,mdy_score,myd_score)
-  max<-max(all_scores,na.rm=TRUE)
+  all_scores <- c(ymd_score, ydm_score, dmy_score, dym_score, mdy_score, myd_score)
+  max <- max(all_scores, na.rm=TRUE)
   return(max)
 }
 
@@ -289,8 +289,9 @@ get_max_score_within_data_formats<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is YMD
-choose_ymd_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_ymd_date_format(df_column) & sum(find_ymd_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_ymd_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_ymd_date_format(df_column) &
+    sum(find_ymd_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
 
@@ -299,8 +300,9 @@ choose_ymd_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is DMY
-choose_dmy_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_dmy_date_format(df_column) & sum(find_dmy_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_dmy_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_dmy_date_format(df_column) &
+    sum(find_dmy_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
 
@@ -309,8 +311,9 @@ choose_dmy_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is MDY
-choose_mdy_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_mdy_date_format(df_column) & sum(find_mdy_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_mdy_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_mdy_date_format(df_column) &
+    sum(find_mdy_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
 
@@ -319,8 +322,9 @@ choose_mdy_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is YDM
-choose_ydm_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_ydm_date_format(df_column) & sum(find_ydm_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_ydm_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_ydm_date_format(df_column) &
+    sum(find_ydm_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
 
@@ -329,8 +333,9 @@ choose_ydm_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is MYD
-choose_myd_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_myd_date_format(df_column) & sum(find_myd_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_myd_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_myd_date_format(df_column) &
+    sum(find_myd_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
 
@@ -339,7 +344,8 @@ choose_myd_format<-function(df_column){
 #' @param df_column data frame date column or vector with dates
 #' @author Lukasz Andrzejewski
 #' @return logical vector, TRUE if most probable date format is DYM
-choose_dym_format<-function(df_column){
-  dates_yn<-find_only_dates(df_column) & find_dym_date_format(df_column) & sum(find_dym_date_format(df_column))==get_max_score_within_data_formats(df_column)
+choose_dym_format <- function(df_column)  {
+  dates_yn <- find_only_dates(df_column) & find_dym_date_format(df_column) &
+    sum(find_dym_date_format(df_column)) == get_max_score_within_data_formats(df_column)
   return(dates_yn)
 }
